[PATCH] Fix PR34706, PR34683 -- use more precise types for fortran arrays
Janus Weil
jaydub66@googlemail.com
Wed Jan 9 06:47:00 GMT 2008
Btw, with 131401 and your patch, compiling with -O3 uses even less
memory than -O1 -fstrict-aliasing (only 390MB, most of the stuff in
"tree operand scan" went away), but it's slower (51 sec).
While -O2 is worse (97sec, 670MB).
2008/1/8, Janus Weil <jaydub66@googlemail.com>:
> Hi Richard,
> thanks for taking care of this. Already the other patches you
> committed in connection with PR34683 have helped a bit. With rev.
> 131401 the test case compiles in about 60sec using 570MB of memory
> (with -O1 -fstrict aliasing). This is already significantly better
> than the 800MB from before.
> After applying your trans-types.c patch, this further improves to
> 33sec and 440MB. Which is nice, but still way above last years'
> October builds. Most of the memory is still used for "tree operand
> scan" and "tree FRE". So I guess there still must be something going
> wrong.
> But I think this patch is fine.
> Cheers,
> Janus
More information about the Fortran
mailing list